<h2>Print Word Document - Windows and Mac</h2>
<b>---  Work in progress  ---</b>
<p>Simple package to print Google documents, works for Windows and Mac</p>

<h3>Installation:</h3>

```
    pip install PrintDocx
```

<h3>Print document:</h3>

```
    import PrintDocx
    
    PrintDocx.PrintDocument(filename, printer_name)
```
